toMgoPublicKey method

String toMgoPublicKey()

Return the Mgo representation of the public key encoded in base-64. A Mgo public key is formed by the concatenation of the scheme flag with the raw bytes of the public key

Implementation

String toMgoPublicKey() {
	return base64Encode(toMgoBytes());
}