MgoAccount class

Constructors

MgoAccount(Keypair keypair)
MgoAccount.ed25519Account()
factory
MgoAccount.fromMnemonics(String mnemonics, SignatureScheme scheme, {int accountIndex = 0, int addressIndex = 0, int changeIndex = 0})
factory
MgoAccount.fromPrivateKey(String privateKey, [SignatureScheme? scheme])
factory
MgoAccount.fromPrivKey(String privateKey)
Bech32 encoded string starting with mgoprivkey.
factory
MgoAccount.secp256k1Account()
factory
MgoAccount.secp256r1Account()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
keyPair Keypair
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAddress() MgoAddress
getPublicKey() Uint8List
getSecretKey() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
privateKey() MgoAddress
This returns the Bech32 secret key string for this keypair.
privateKeyHex() MgoAddress
signData(Uint8List data) SignaturePubkeyPair
toString() MgoAddress
A string representation of this object.
inherited
verify(Uint8List data, SignaturePubkeyPair signature) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateMnemonic({int strength = 128}) String
isValidAddress(String address) bool
isValidMgoNS(String name) bool
isValidMnemonics(String mnemonics) bool