MgoMoveNormalizedFunction class

Constructors

MgoMoveNormalizedFunction(MgoMoveVisibility visibility, bool? isEntry, List<MgoMoveAbilitySet> typeParameters, List<MgoMoveNormalizedType> parameters, List<MgoMoveNormalizedType> returns)
MgoMoveNormalizedFunction.fromJson(dynamic data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEntry bool?
getter/setter pair
parameters List<MgoMoveNormalizedType>
getter/setter pair
returns List<MgoMoveNormalizedType>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeParameters List<MgoMoveAbilitySet>
getter/setter pair
visibility MgoMoveVisibility
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited