MgoMoveNormalizedModule class

Constructors

MgoMoveNormalizedModule(int fileFormatVersion, String address, String name, List<MgoMoveModuleId> friends, Map<String, MgoMoveNormalizedStruct> structs, Map<String, MgoMoveNormalizedFunction> exposedFunctions)
MgoMoveNormalizedModule.fromJson(dynamic data)
factory

Properties

address String
getter/setter pair
exposedFunctions Map<String, MgoMoveNormalizedFunction>
getter/setter pair
fileFormatVersion int
getter/setter pair
friends List<MgoMoveModuleId>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structs Map<String, MgoMoveNormalizedStruct>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited