MgoData class
Constructors
- MgoData(ObjectType dataType, MgoMoveObject moveObject, MgoMovePackage movePackage)
Properties
- dataType ↔ ObjectType
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- moveObject ↔ MgoMoveObject
-
getter/setter pair
- movePackage ↔ MgoMovePackage
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → TransactionDigest -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited