MgoObject class

Inheritance

Constructors

MgoObject(String objectId, String digest, int version, String? type, MgoMoveObject? content, MgoRawMoveObject? bcs, ObjectOwner? owner, TransactionDigest? previousTransaction, String? storageRebate, DisplayFieldsResponse? display)
MgoObject.fromJson(dynamic data)
factory

Properties

bcs MgoRawMoveObject?
Move object content or package content in BCS bytes, default to be undefined unless MgoObjectDataOptions.showBcs is set to true
getter/setter pair
content MgoMoveObject?
Move object content or package content, default to be undefined unless MgoObjectDataOptions.showContent is set to true
getter/setter pair
digest TransactionDigest
Base64 string representing the object digest
getter/setter pairinherited
display DisplayFieldsResponse?
Display metadata for this object, default to be undefined unless MgoObjectDataOptions.showDisplay is set to true This can also be None if the struct type does not have Display defined See more details in https://forums.mgo.io/t/nft-object-display-proposal/4872
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
objectId TransactionDigest
Hex code as string representing the object id
getter/setter pairinherited
owner ObjectOwner?
The owner of this object. Default to be undefined unless MgoObjectDataOptions.showOwner is set to true
getter/setter pair
previousTransaction TransactionDigest?
The digest of the transaction that created or last mutated this object. Default to be undefined unless MgoObjectDataOptions.showPreviousTransaction is set to true
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageRebate TransactionDigest?
The amount of MGO we would rebate if this object gets deleted. This number is re-calculated each time the object is mutated based on the present storage gas price. Default to be undefined unless MgoObjectDataOptions.showStorageRebate is set to true
getter/setter pair
type TransactionDigest?
Type of the object, default to be undefined unless MgoObjectDataOptions.showType is set to true
getter/setter pair
version int
Object version
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() TransactionDigest
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited