MgoTransactionKind class

Constructors

MgoTransactionKind(TransferObject? transferObject, MgoMovePackage? publish, MoveCall? call, MgoTransferMgo? transferMgo, MgoChangeEpoch? changeEpoch, Pay? pay, PayMgo? payMgo, PayAllMgo? payAllMgo)
MgoTransactionKind.fromJson(dynamic data)
factory

Properties

call MoveCall?
getter/setter pair
changeEpoch MgoChangeEpoch?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pay Pay?
getter/setter pair
payAllMgo PayAllMgo?
getter/setter pair
payMgo PayMgo?
getter/setter pair
publish MgoMovePackage?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transferMgo MgoTransferMgo?
getter/setter pair
transferObject TransferObject?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited